export declare enum Type {
    DEFAULT = "default",
    INFO = "info",
    SUCCESS = "success",
    WARNING = "warning",
    ERROR = "error",
}
/**
 * **Ignite UI for Angular Badge** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/badge.html)
 *
 * The Ignite UI Badge is used to decorate avatars, navigation menus, or other components in the
 * application when visual notification is needed. They are usually designed as icons with a predefined
 * style to communicate information, success, warnings, or errors.
 *
 * Example:
 * ```html
 * <igx-avatar icon="person" roundShape="true" size="small">
 *   <igx-badge icon="check" type="success" class="badge-style">
 *   </igx-badge>
 * </igx-avatar>
 * ```
 * The `badge-style` class is used to position the badge:
 * ```css
 * .badge-style {
 *   position: absolute;
 *   bottom: -6px;
 *   right:-50px;
 * }
 * ```
 */
export declare class IgxBadgeComponent {
    /**
     * An @Input property that sets the value of the `id` attribute.
     */
    id: string;
    /**
    * An @Input property controlling the type of the badge.
    * Allowed values are `default`, `info`, `success`, `warning`, `error`.
    * Providing an invalid value won't display a badge.
    */
    type: string | Type;
    /**
    * An @Input property that sets the value to be displayed inside the badge.
    * If an `icon` property is already set the `icon` will be displayed.
    * If neither a `value` nor an `icon` is set the contentent of the badge will be empty.
    */
    value: string;
    /**
     * Set an icon for the badge from the material icons set.
     * Has priority over the `value` property.
     * If neither a `value` nor an `icon` is set the content of the badge will be empty.
     * Providing an invalid value won't display anything.
     */
    icon: string;
    /**
     * Set the value of the `role` attribute.
     */
    role: string;
    /**
     * This allows you to set class to the badge. The default value is igx-badge.
     */
    cssClass: string;
    /**
     * Set the value of the `aria-label` attribute.
     */
    label: string;
    /**
     * Defines a human-readable, accessor, author-localized description for the `type` and the `icon` or `value` of the element.
     */
    readonly roleDescription: any;
    /**
     *
     * Method which makes the name of the class more descriptive.
     * This helps the styling of the badges.
     */
    setClasses(): {};
}
export declare class IgxBadgeModule {
}
