import { ElementRef, EventEmitter, QueryList, TemplateRef } from '@angular/core';
import { IgxListItemComponent } from './list-item.component';
import { IgxEmptyListTemplateDirective, IgxListPanState } from './list.common';
export interface IPanStateChangeEventArgs {
    oldState: IgxListPanState;
    newState: IgxListPanState;
    item: IgxListItemComponent;
}
export interface IListItemClickEventArgs {
    item: IgxListItemComponent;
    event: Event;
}
/**
 * **Ignite UI for Angular List** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/list.html)
 *
 * The Ignite UI List displays rows of items and supports one or more header items as well as search and filtering
 * of list items. Each list item is completely templateable and will support any valid HTML or Angular component.
 *
 * Example:
 * ```html
 * <igx-list>
 *   <igx-list-item isHeader="true">Contacts</igx-list-item>
 *   <igx-list-item *ngFor="let contact of contacts">
 *     <span class="name">{{ contact.name }}</span>
 *     <span class="phone">{{ contact.phone }}</span>
 *   </igx-list-item>
 * </igx-list>
 * ```
 */
export declare class IgxListComponent {
    private element;
    constructor(element: ElementRef);
    children: QueryList<IgxListItemComponent>;
    emptyListTemplate: IgxEmptyListTemplateDirective;
    protected defaultEmptyListTemplate: TemplateRef<any>;
    id: string;
    allowLeftPanning: boolean;
    allowRightPanning: boolean;
    onLeftPan: EventEmitter<IgxListItemComponent>;
    onRightPan: EventEmitter<IgxListItemComponent>;
    onPanStateChange: EventEmitter<IPanStateChangeEventArgs>;
    onItemClicked: EventEmitter<IListItemClickEventArgs>;
    readonly role: string;
    readonly isListEmpty: boolean;
    readonly cssClass: boolean;
    readonly items: IgxListItemComponent[];
    readonly headers: IgxListItemComponent[];
    readonly context: any;
    readonly template: TemplateRef<any>;
}
export declare class IgxListModule {
}
