import { AnimationEvent } from '@angular/animations';
import { EventEmitter, NgZone } from '@angular/core';
export declare class IgxSnackbarComponent {
    private zone;
    /** ID of the component */
    id: string;
    /**
     * The message that will be shown message by the IgxSnackbar component
     */
    message: string;
    /**
     * The IgxSnackbar component visual state state
     */
    isVisible: boolean;
    /**
     * Sets if the IgxSnackbar component will be hidden after shown
     * Default value is true
     */
    autoHide: boolean;
    /**
     * The duration of time span in ms which the IgxSnackbar component will be visible
     * after it is being shown.
     * Default value is 4000
     */
    displayTime: number;
    /**
     * The text of the IgxSnackbar component action
     */
    actionText?: string;
    /**
     * The event that will be thrown when the action is executed,
     * provides reference to the IgxSnackbar component as argument
     */
    onAction: EventEmitter<IgxSnackbarComponent>;
    /**
     * The event that will be thrown when the snackbar animation starts
     */
    animationStarted: EventEmitter<AnimationEvent>;
    /**
     * The event that will be thrown when the snackbar animation ends
     */
    animationDone: EventEmitter<AnimationEvent>;
    private timeoutId;
    constructor(zone: NgZone);
    /**
     * Shows the IgxSnackbar component and hides it after some time span
     * if autoHide is enabled
     */
    show(): void;
    /**
     * Hides the IgxSnackbar component
     */
    hide(): void;
    triggerAction(): void;
    snackbarAnimationStarted(evt: AnimationEvent): void;
    snackbarAnimationDone(evt: AnimationEvent): void;
}
export declare class IgxSnackbarModule {
}
