import { ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { HammerGestureConfig } from '@angular/platform-browser';
export declare class TimePickerHammerConfig extends HammerGestureConfig {
    overrides: {
        pan: {
            direction: number;
            threshold: number;
        };
    };
}
export interface IgxTimePickerValueChangedEventArgs {
    oldValue: Date;
    newValue: Date;
}
export interface IgxTimePickerValidationFailedEventArgs {
    timePicker: IgxTimePickerComponent;
    currentValue: Date;
    setThroughUI: boolean;
}
export declare class IgxTimePickerComponent implements ControlValueAccessor, OnInit, OnDestroy {
    private _value;
    /** ID of the component */
    id: string;
    value: Date;
    isDisabled: boolean;
    okButtonLabel: string;
    cancelButtonLabel: string;
    itemsDelta: {
        hours: number;
        minutes: number;
    };
    minValue: string;
    maxValue: string;
    isSpinLoop: boolean;
    vertical: boolean;
    format: string;
    onValueChanged: EventEmitter<IgxTimePickerValueChangedEventArgs>;
    onValidationFailed: EventEmitter<IgxTimePickerValidationFailedEventArgs>;
    onOpen: EventEmitter<IgxTimePickerComponent>;
    hourList: ElementRef;
    minuteList: ElementRef;
    ampmList: ElementRef;
    private _alert;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    readonly styleClass: string;
    /**
     * @hidden
     */
    _hourItems: any[];
    /**
     * @hidden
     */
    _minuteItems: any[];
    /**
     * @hidden
     */
    _ampmItems: any[];
    private _isHourListLoop;
    private _isMinuteListLoop;
    private _hourView;
    private _minuteView;
    private _ampmView;
    /**
     * @hidden
     */
    selectedHour: string;
    /**
     * @hidden
     */
    selectedMinute: string;
    /**
     * @hidden
     */
    selectedAmPm: string;
    private _prevSelectedHour;
    private _prevSelectedMinute;
    private _prevSelectedAmPm;
    readonly displayTime: string;
    readonly hourView: string[];
    readonly minuteView: string[];
    readonly ampmView: string[];
    onClick(): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    writeValue(value: Date): void;
    registerOnChange(fn: (_: Date) => void): void;
    registerOnTouched(fn: () => void): void;
    private _onTouchedCallback;
    private _onChangeCallback;
    private _scrollItemIntoView(item, items, selectedItem, isListLoop, viewType);
    private _viewToString(view, viewType);
    private _itemToString(item, viewType);
    private _prevItem(items, selectedItem, isListLoop, viewType);
    private _nextItem(items, selectedItem, isListLoop, viewType);
    private _formatTime(value, format);
    private _updateHourView(start, end);
    private _updateMinuteView(start, end);
    private _updateAmPmView(start, end);
    private _addEmptyItems(items);
    private _generateHours();
    private _generateMinutes();
    private _generateAmPm();
    private _getSelectedTime();
    private _convertMinMaxValue(value);
    private _isValueValid(value);
    /**
     * Scrolls a hour item into view.
     * @param item to be scrolled in view.
     */
    scrollHourIntoView(item: string): void;
    /**
     * Scrolls a minute item into view.
     * @param item to be scrolled in view.
     */
    scrollMinuteIntoView(item: string): void;
    /**
     * Scrolls an ampm item into view.
     * @param item to be scrolled in view.
     */
    scrollAmPmIntoView(item: string): void;
    /**
     * @hidden
     */
    nextHour(): void;
    /**
     * @hidden
     */
    prevHour(): void;
    /**
     * @hidden
     */
    nextMinute(): void;
    /**
     * @hidden
     */
    prevMinute(): void;
    /**
     * @hidden
     */
    nextAmPm(): void;
    /**
     * @hidden
     */
    prevAmPm(): void;
    okButtonClick(): boolean;
    cancelButtonClick(): void;
    hoursInView(): string[];
    minutesInView(): string[];
    ampmInView(): string[];
}
export declare class IgxTimePickerModule {
}
