import { ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { IgxNavigationService, IToggleView } from '../core/navigation';
export declare class IgxToastComponent implements IToggleView, OnInit, OnDestroy {
    private elementRef;
    private navService;
    readonly CSS_CLASSES: {
        IGX_TOAST_BOTTOM: string;
        IGX_TOAST_MIDDLE: string;
        IGX_TOAST_TOP: string;
    };
    /**
     * Identifier of the component
     */
    id: string;
    /**
     * Event is thrown prior toast is shown
     */
    onShowing: EventEmitter<IgxToastComponent>;
    /**
     * Event is shown when toast is shown
     */
    onShown: EventEmitter<IgxToastComponent>;
    /**
     * Event is thrown prior toast hidden
     */
    onHiding: EventEmitter<IgxToastComponent>;
    /**
     * Event is thrown when toast hidden
     */
    onHidden: EventEmitter<IgxToastComponent>;
    role: string;
    /**
     * Sets if the IgxToast component will be hidden after shown
     * Default value is true
     */
    autoHide: boolean;
    /**
     * The duration of time span in ms which the IgxToast component will be visible
     * after it is being shown.
     * Default value is 4000
     */
    displayTime: number;
    /**
     * The IgxToast component visual state state
     */
    isVisible: boolean;
    /**
     * The message that will be shown message by the IgxToast component
     */
    message: string;
    /**
     * Specifies the position of the IgxToast component. Possible options are IgxToastPosition.Top,
     * IgxToastPosition.Middle, IgxToastPosition.Bottom
     */
    position: IgxToastPosition;
    /**
     * Return the nativeElement of the component
     */
    readonly element: any;
    private timeoutId;
    constructor(elementRef: ElementRef, navService: IgxNavigationService);
    /**
     * Shows the IgxToast component and hides it after some time span
     * if autoHide is enabled
     */
    show(): void;
    /**
     * Hides the IgxToast component
     */
    hide(): void;
    /**
     * Wraps @show() method due @IToggleView interface implementation.
     */
    open(): void;
    /**
     * Wraps @hide() method due @IToggleView interface implementation.
     */
    close(): void;
    /**
     * Invoke @close() or @open() method depending on the state of the component.
     */
    toggle(): void;
    mapPositionToClassName(): any;
    ngOnInit(): void;
    ngOnDestroy(): void;
}
/**
 * Enumeration for toast position
 * Can be:
 * Bottom
 * Middle
 * Top
 */
export declare enum IgxToastPosition {
    Bottom = 0,
    Middle = 1,
    Top = 2,
}
export declare class IgxToastModule {
}
